@@ -122,7 +122,7 @@ class TestProcessorRegex(unittest.TestCase):
             'topic': 'org.fedoraproject.dev.git.push',
         }
         result = self.proc.handle_msg(fake_message, **self.config)
-        assert result, "Proc didn't say it could handle the message."
+        assert result is not None, "Proc didn't say it could handle the message."
 
     def test_processor_handle_miss(self):
         """ Test that a proc says it won't handle what it shouldn't. """
@@ -130,13 +130,21 @@ class TestProcessorRegex(unittest.TestCase):
             'topic': 'org.fedoraproject.dev.github.push',
         }
         result = self.proc.handle_msg(fake_message, **self.config)
-        assert not result, "Proc falsely claimed it could handle the msg."
+        assert result is None, "Proc falsely claimed it could handle the msg."
 
+    def test_processor_handle_empty_subtopic(self):
+        """Test that a processor will handle a message with an empty subtopic"""
+        fake_message = {
+            'topic': 'org.fedoraproject.dev.git',
+        }
+        result = self.proc.handle_msg(fake_message, **self.config)
+        assert result is "", "Proc said it couldn't handle the msg."
 
 class Base(unittest.TestCase):
     msg = None
     expected_title = None
     expected_subti = None
+    expected_markup = None
     expected_link = None
     expected_icon = None
     expected_secondary_icon = None
@@ -162,6 +170,13 @@ class Base(unittest.TestCase):
         actual_title = fedmsg.meta.msg2title(self.msg, **self.config)
         eq_(actual_title, self.expected_title)
 
+    @skip_on(['msg', 'expected_markup'])
+    def test_markup(self):
+        """ Does fedmsg.meta produce the right html when markup=True? """
+        actual_markup = fedmsg.meta.msg2subtitle(
+            self.msg, markup=True, **self.config)
+        eq_(actual_markup, self.expected_markup)
+
     @skip_on(['msg', 'expected_subti'])
     def test_subtitle(self):
         """ Does fedmsg.meta produce the expected subtitle? """
